
# Slot: id


Books should have industry-standard identifier such as from ISBN.

URI: [biolink:book_id](https://w3id.org/biolink/vocab/book_id)


## Domain and Range

[Book](Book.md) &#8594;  <sub>1..1</sub> [String](types/String.md)

## Parents

 *  is_a: [publication➞id](publication_id.md)

## Children


## Used by

 * [Book](Book.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |
| **Exact Mappings:** | | alliancegenome:primaryId |
|  | | gff3:ID |
|  | | gpi:DB_Object_ID |

